@@ -4,27 +4,33 @@ use strict;
 use Math::Random;
 use vars qw($VERSION);
 
-$VERSION = '1.00';
+$VERSION = '1.01';
 
 sub new {
   my $package = shift;
   my %opts = @_;
   $opts{lc $_} = delete $opts{$_} for keys %opts;
   $opts{dict} = '/usr/share/dict/words' unless $opts{dict};
+  $opts{key} =~ s/[^A-Za-z]//g if $opts{key};
   my $self = bless \%opts, $package;
+
+  $self->{poe} = [ $opts{key}? split( //, $opts{key} ) : qw(p o e) ];
+  my $key = join '', @{$self->{poe}};
+
   if ( $opts{wordlist} and ref $opts{wordlist} eq 'ARRAY' ) {
 	for ( @{ $opts{wordlist} } ) {
 	   chomp;
-	   next unless /^[poe]\w+$/;
+	   next unless /^[$key]\w+$/;
 	   push @{ $self->{words}->{ substr($_,0,1) } }, $_;
 	}
 	return $self;
   }
   if ( -e $opts{dict} ) {
-	open my $fh, "<", $self->{dict} or die "$!\n";
+	open my $fh, '<', $self->{dict} or die "$!\n";
 	while (<$fh>) {
 	   chomp;
-	   next unless /^[poe]\w+$/;
+	   next unless /^[$key]\w+$/;
+	   # next unless /^[poe]\w+$/;
 	   push @{ $self->{words}->{ substr($_,0,1) } }, $_;
 	}
 	close $fh;
@@ -45,7 +51,7 @@ sub generate {
   my $words = $self->{words};
   my @poe;
   push @poe, 
-	ucfirst( $words->{$_}->[ scalar random_uniform_integer(1,0,$#{ $words->{$_} } ) ] ) for qw(p o e);
+	ucfirst( $words->{$_}->[ scalar random_uniform_integer(1,0,$#{ $words->{$_} } ) ] ) for ( @{$self->{poe}} );
   return wantarray ? @poe : join( ' ', @poe );
 }
 
@@ -72,7 +78,8 @@ Acme::POE::Acronym::Generator - Generate random POE acronyms.
 
 What does POE stand for?" is a common question, and people have expanded the acronym in several ways.
 
-Acme::POE::Acronym::Generator produces randomly generated expansions of the POE acronym.
+Acme::POE::Acronym::Generator produces randomly generated expansions of the POE acronym ( or at your
+option any other arbitary word ).
 
 =head1 CONSTRUCTOR
 
@@ -80,10 +87,11 @@ Acme::POE::Acronym::Generator produces randomly generated expansions of the POE
 
 =item new
 
-Takes two optional parameters:
+Takes three optional parameters:
 
   'dict', the path to the words file to use, default is /usr/share/dict/words;
   'wordlist', an arrayref consisting of words to use, this overrides the use of dict file;
+  'key', provide a word to make an acronym for instead of POE;
 
 If the dict file doesn't exist it will use a very small subset of words to generate responses.
 
